{% extends "auth/base.html" %}
{% import "bootstrap/wtf.html" as wtf %}


{% block page_content %}

<div class="content-section">

    <a href="{{ back_url }}"><button type="button" class="btn btn-light btn-lg mb-3"><i class="fas fa-chevron-circle-left mr-3"></i>Return to Previous Page</button></a>
    <form method="POST" action="">
        {{ form.csrf_token }}
        <fieldset class="form-group">
            <legend class="border-bottom mb4">{{ title }}</legend>
        
            <div class="form-group">
                {{ wtf.form_field(form.name, class='form-control') }}
                {% for error in form.name.errors %}
                        <div class="alert alert-danger">{{ error }} </div>
                {% endfor %}
            </div>
            <div class="form-group">
                {{ wtf.form_field(form.notes, class='form-control') }}
                {% for error in form.notes.errors %}
                        <div class="alert alert-danger">{{ error }} </div>
                {% endfor %}
            </div>
        </fieldset>
        <div class="mb-5"> 
            {{ wtf.form_field(form.submit, class="btn btn-primary form-control") }}
        </div>
    </form>
</div>
</div>


{% endblock %}

