{% extends "auth/base.html" %}
{% import "bootstrap/wtf.html" as wtf %}


{% block page_content %}
<div class="page-header">
    <h1>Reset Your Password</h1>
</div>
<div class="col-md-4">
    {{ wtf.quick_form(form) }}
</div>
{% endblock %}